Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(497)

Unified Diff: webkit/glue/webframeloaderclient_impl.h

Issue 149620: Use WebWidget from the WebKit API. This change also makes... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/glue/inspector_client_impl.cc ('k') | webkit/glue/webframeloaderclient_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/webframeloaderclient_impl.h
===================================================================
--- webkit/glue/webframeloaderclient_impl.h (revision 20851)
+++ webkit/glue/webframeloaderclient_impl.h (working copy)
@@ -5,18 +5,13 @@
#ifndef WEBKIT_GLUE_WEBFRAMELOADERCLIENT_IMPL_H__
#define WEBKIT_GLUE_WEBFRAMELOADERCLIENT_IMPL_H__
-#include "base/compiler_specific.h"
-
-MSVC_PUSH_WARNING_LEVEL(0);
#include "FrameLoaderClient.h"
#include <wtf/RefPtr.h>
-MSVC_POP_WARNING();
-#include "build/build_config.h"
#include "base/scoped_ptr.h"
#include "googleurl/src/gurl.h"
+#include "webkit/api/public/WebNavigationPolicy.h"
#include "webkit/glue/webview_delegate.h"
-#include "webkit/glue/window_open_disposition.h"
namespace WebCore {
class Frame;
@@ -217,11 +212,11 @@
private:
void makeDocumentView();
- // Given a NavigationAction, determine the associated window opening
- // disposition. For example, a middle click means "open in background tab".
- static bool ActionSpecifiesDisposition(
+ // Given a NavigationAction, determine the associated WebNavigationPolicy.
+ // For example, a middle click means "open in background tab".
+ static bool ActionSpecifiesNavigationPolicy(
const WebCore::NavigationAction& action,
- WindowOpenDisposition* disposition);
+ WebKit::WebNavigationPolicy* policy);
// Returns a valid GURL if we have an alt 404 server URL.
GURL GetAlt404PageUrl(WebCore::DocumentLoader* loader);
@@ -264,8 +259,8 @@
// which specifies that the plugin should be ready to accept data.
bool sent_initial_response_to_plugin_;
- // The disposition to use for the next call to dispatchCreatePage.
- WindowOpenDisposition next_window_open_disposition_;
+ // The navigation policy to use for the next call to dispatchCreatePage.
+ WebKit::WebNavigationPolicy next_navigation_policy_;
};
#endif // #ifndef WEBKIT_GLUE_WEBFRAMELOADERCLIENT_IMPL_H__
« no previous file with comments | « webkit/glue/inspector_client_impl.cc ('k') | webkit/glue/webframeloaderclient_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698